@@ -3,7 +3,7 @@
 # File: .......................... API.pm
 # Original Author: ............... Jeff Nokes
 # Last Modifed By: ............... Bob Bradley / Jeff Nokes
-# Last Modified: ................. 03/30/2007 @ 18:00
+# Last Modified: ................. 03/30/2007 @ 23:09
 #
 # Description
 #
@@ -40,7 +40,7 @@
   # none
 
 # Globals
-  our $VERSION = '0.21';
+  our $VERSION = '0.22';
 
 # Lexicals
   # none
@@ -250,12 +250,12 @@ The package includes tools to auto generate all classes needed to
 invoke any published eBay XML API web service, including accessing all
 data components accepted and delivered by the web services.
 
-   lib/eBay/API/XML/tools/codegen/xsd
+   lib/eBay/API/XML/Tools/CodeGen/XSD
 
 There is also a tool to generate indexed HTML documenation for every package
 included in this library, or generated by this library.
 
-   lib/eBay/API/XML/tools/doc
+   lib/eBay/API/XML/Tools/Doc
 
 =head3 Auto Generation of Call & Data type Classes
 
@@ -277,7 +277,7 @@ transparently keep up with these enhancements and make them directly
 available to your API-enabled applications as new versions of the eBay
 API become available.
 
-Consult the README file in lib/eBay/API/XML/tools/codegen/xsd for
+Consult the README file in lib/eBay/API/XML/Tools/CodeGen/XSD for
 instructions on how to update your generated eBay XML API web services
 class library.
 
@@ -303,7 +303,7 @@ the generated classes only exists in POD format.
 
 Using the genhtmldoc.pl tool (mentioned above in the Tools section),
 you can create a library of indexed HTML documentation.  Consult the README
-file in lib/eBay/API/XML/tools/doc for details on how to compile and access
+file in lib/eBay/API/XML/Tools/Doc for details on how to compile and access
 HTML manual pages for the generated classes from a web browser.
 
 
